<#
.SYNOPSIS
Baseline DSC-Konfigurasjon som gjelder alle SessionHosts.


.DESCRIPTION
Dette er baseline DSC-konfigurasjonen for SessionHosts. Utviklet av Øyvind Lotten Westrum i forbindelse med Bachelorprosjekt våren 2019. Oppgaven gikk ut på å konfigurere en Session Host uten manuelle steg ved bruk av Azure Automation Desired State Configuration.

Konfigurasjonen er en Composite Resource med navn "SessionHostBaseline" der all konfigurasjon som er felles for alle Session Hoster er definert.

Konfigurasjonen benytter følgende egenkomposerte/videreutviklede DSC-ressurser som må importeres i Azure Automation:
- IPv6Address
- Printer
- PrinterDriver
- #SessionHost (NB. Ikke testet i testmiljø)


.EXAMPLE

Mappestruktur:
$env: psmodulepath
    |- MyDscResources
           MyDscResources.psd1
        |- DSCResources
            |- SessionHostBaseline
                |- SessionHostBaseline.psd1 <-- Module manifest
                |- SessionHostBaseline.schema.psm1 <-- Denne filen

#>
Configuration SessionHostBaseline
{
    Import-DscResource -ModuleName ComputerManagementDsc -name VirtualMemory
    Import-DscResource -ModuleName PSDesiredStateConfiguration -name WindowsFeatureSet
    Import-DscResource -ModuleName AzureDSC_Modules -name IPv6Address
    Import-DscResource -ModuleName AzureDSC_Modules -name PrinterDriver
    Import-DscResource -ModuleName AzureDSC_Modules -name Printer
    #Import-DscResource -ModuleName AzureDSC_Modules -name SessionHost
    
    VirtualMemory PagingSettings
    {
        Type                    = "CustomSize"
        Drive                   = "C"
        InitialSize             = "10000"
        MaximumSize             = "20000"
    }
    IPv6Address ConfigureIPv6SiteLocal
    {
        NetIPv6Address          = "fdd2:2868:bf02:7777::"
    }
    WindowsFeatureSet InstallWindowsFeaturesBase
    {
        Name                    = @("RDS-RD-Server", "XPS-Viewer", "NET-Framework-Core")
        Ensure                  = "Present"
    }
    PrinterDriver AddPrinterDriver
    {
        DriverName              = "Xerox Global Print Driver PS"
        Environment             = "x64"
        Ensure                  = "Present"
        TPInfPath               = "\\win.ntnu.no\shares\installshare\pakker\dagens\Legg til skriver\Xerox Generic PS\X-GPD_5.273.23.2_PS_x64_Driver.inf\x2UNIVP.inf"
    }
    Printer AddPrinter
    {
        Name                    = "Xerox Global Print Driver PS"
        DriverName              = "Xerox Global Print Driver PS"
        PortName                = "portprompt:"
        Ensure                  = "Present"
        Published               = $false
        DependsOn               = "[PrinterDriver]AddPrinterDriver"
    }
    # SessionHost Test
    # {
    #     ConnectionBroker            = "it-rdconnect01.win.ntnu.no"
    #     Collection                  = "Azdscfarm"
    #     NewConnectionAllowed        = "No"
    # }
}
