<#
.SYNOPSIS
Konfigurere LCM og onboarde maskiner til Azure Automation.


.DESCRIPTION
Scriptet er hentet fra https://docs.microsoft.com/en-us/azure/automation/automation-dsc-onboarding#generating-dsc-metaconfigurations

Men er tilpasset for å ta inn parametere fra konfigurasjonsdata.
Det burde videre utvides ved å sjekke om den kompilerte konfigurasjonen eksisterer på pull-server.


.EXAMPLE
1. Kjør scriptet
2. Kjør Set-DscLocalConfigurationManager -Path ./DscMetaConfigs

#>

# The DSC configuration that will generate metaconfigurations
[DscLocalConfigurationManager()]
Configuration DscMetaConfigs
{
     param
     (
         [Parameter(Mandatory=$True)]
         [String]$RegistrationUrl,

         [Parameter(Mandatory=$True)]
         [String]$RegistrationKey,

         [Parameter(Mandatory=$True)]
         [String[]]$ComputerName,

         [Int]$RefreshFrequencyMins = 30,

         [Int]$ConfigurationModeFrequencyMins = 15,

         [String]$ConfigurationMode = 'ApplyAndMonitor',

         [String]$NodeConfigurationName,

         [Boolean]$RebootNodeIfNeeded= $False,

         [String]$ActionAfterReboot = 'ContinueConfiguration',

         [Boolean]$AllowModuleOverwrite = $False,

         [Boolean]$ReportOnly
     )

     if(!$NodeConfigurationName -or $NodeConfigurationName -eq '')
     {
         $ConfigurationNames = $null
     }
     else
     {
         $ConfigurationNames = @($NodeConfigurationName)
     }

     if($ReportOnly)
     {
         $RefreshMode = 'PUSH'
     }
     else
     {
         $RefreshMode = 'PULL'
     }

     Node $ComputerName
     {
         Settings
         {
             RefreshFrequencyMins           = $RefreshFrequencyMins
             RefreshMode                    = $RefreshMode
             ConfigurationMode              = $ConfigurationMode
             AllowModuleOverwrite           = $AllowModuleOverwrite
             RebootNodeIfNeeded             = $RebootNodeIfNeeded
             ActionAfterReboot              = $ActionAfterReboot
             ConfigurationModeFrequencyMins = $ConfigurationModeFrequencyMins
         }

         if(!$ReportOnly)
         {
         ConfigurationRepositoryWeb AzureAutomationStateConfiguration
             {
                 ServerUrl          = $RegistrationUrl
                 RegistrationKey    = $RegistrationKey
                 ConfigurationNames = $ConfigurationNames
             }

             ResourceRepositoryWeb AzureAutomationStateConfiguration
             {
                 ServerUrl       = $RegistrationUrl
                 RegistrationKey = $RegistrationKey
             }
         }

         ReportServerWeb AzureAutomationStateConfiguration
         {
             ServerUrl       = $RegistrationUrl
             RegistrationKey = $RegistrationKey
         }
     }
}

#
# Edit below this line
# --------------------------------------------------------------------------

# ConfigurationData
# New computers are added here.
$ConfigData =
@{
    AllNodes =
    @(
        @{
            NodeName             = "it-azdscfarm01"
            Collection           = "azdscfarm"
            OS                   = "srv2016"
            Configuration        = "SessionHost"
            ConfigurationMode    = "ApplyAndMonitor"
        },
        @{
            NodeName             = "it-azdscfarm02"
            Collection           = "calcfarm"
            OS                   = "srv2016"
            Configuration        = "SessionHost"
            ConfigurationMode    = "ApplyAndMonitor"
        }
    );
}

foreach ($node in $ConfigData.AllNodes) {
 # Create the metaconfigurations
 # NOTE: DSC Node Configuration names are case sensitive in the portal.
 # TODO: edit the below as needed for your use case
    $Params = @{
         RegistrationUrl = ''; # Fill inn URL from Azure Automation
         RegistrationKey = ''; # Fill inn Key from Azure Automation
         ComputerName = $node.NodeName;
         NodeConfigurationName = "$($node.Configuration).$($node.Collection).$($node.OS)";
         RefreshFrequencyMins = 30;
         ConfigurationModeFrequencyMins = 15;
         RebootNodeIfNeeded = $True;
         AllowModuleOverwrite = $False;
         ConfigurationMode = $node.ConfigurationMode;
         ActionAfterReboot = 'ContinueConfiguration';
         ReportOnly = $False;  # Set to $True to have machines only report to AA DSC but not pull from it
    }

    # Use PowerShell splatting to pass parameters to the DSC configuration being invoked
    # For more info about splatting, run: Get-Help -Name about_Splatting
    DscMetaConfigs @Params
}