# Login to Azure Automation
$Login = Connect-AzAccount

# Config
$rg = 'NTNU02-M-northeu-DSC-rg'
$aa = 'azure-dsc-test-01'

# Splatting to make cmdlets easyer to read/write
$P = @{
    ResourceGroupName     = $rg;
    AutomationAccountName = $aa;
}

# ------------------------------------------ Copy 

# Upload DSC Configuration to Azure Automation.
# The filename must be the same as the configurationname. 
$config = Import-AzAutomationDscConfiguration @P -SourcePath "RemoteDesktopServices.ps1" -Published -Force -Verbose

# Compile DSC Configuration. -IncrementNodeConfigurationBuild saves old config.
$CompilateConfig = Start-AzAutomationDscCompilationJob @P -ConfigurationName $config.Name -IncrementNodeConfigurationBuild -Verbose

# ------------------------------------------ Copy 


# Getting Node Configuration name for assigning configurations to nodes.
# Where-Object pga bug -> https://github.com/Azure/azure-powershell/issues/8738
$NodeConfigurations = Get-AzAutomationDscNodeConfiguration @P | Where-Object {$_.ConfigurationName -eq $CompilateConfig.ConfigurationName} | sort-object {[int]($_.ConfigurationName -replace '\D')}
#$NodeConfigurations = Get-AzAutomationDscNodeConfiguration @P -ConfigurationName $CompilateConfig.ConfigurationName

$Node = Get-AzAutomationDscNode @P -Name "IT-AZDSCFARM02"

# Setting Node Configurations to Node ([-1] to get last version)
$SetNodeConfig = Set-AzAutomationDscNode @P -NodeConfigurationName $NodeConfigurations.Name[-1] -Id $Node.Id -Force -Verbose 


# ------------------------------------------ Copy 

# Update all Nodes with newest config
$NodeConfigurations = Get-AzAutomationDscNodeConfiguration @P | Select-Object Name | sort-object {[int]($_.Name -replace '\D')}
$Nodes = Get-AzAutomationDscNode @P
foreach ($Node in $Nodes) {
    $SetNodeConfig = Set-AzAutomationDscNode @P -NodeConfigurationName $NodeConfigurations.Name[-1] -Id $Node.Id -Force -Verbose 
}

# Delete all configs that does not have nodes attatched
$ActiveConfigs = (Get-AzAutomationDscNode @P).NodeConfigurationName
foreach ($ActiveConfig in $ActiveConfigs) {
    Get-AzAutomationDscNodeConfiguration @P | Where-Object -Property Name -NE $ActiveConfig | Remove-AzAutomationDscNodeConfiguration @P -Force -Verbose
}

# ------------------------------------------ Copy 

### BASELINE CONFIG TEST
# Upload DSC Configuration to Azure Automation.
# The filename must be the same as the configurationname. 
$Config = Import-AzAutomationDscConfiguration @P -SourcePath "SessionHost.ps1" -Published -Force -Verbose

$Params = @{
    "OS"="srv2016";
    "Collection"="azdscfarm"
}
# Compile DSC Configuration. -IncrementNodeConfigurationBuild saves old config.
$CompilateConfig = Start-AzAutomationDscCompilationJob @P -Parameters $Params -ConfigurationName $Config.Name -IncrementNodeConfigurationBuild -Verbose

# ------------------------------------------ Copy

$Config = Import-AzAutomationDscConfiguration @P -SourcePath "SessionHost.ps1" -Published -Force -Verbose

$CompilateConfig = Start-AzAutomationDscCompilationJob @P -ConfigurationName $Config.Name -ConfigurationData $(Import-PowerShellDataFile -Path ConfigData.psd1) -IncrementNodeConfigurationBuild -Verbose

## Module

Get-AzAutomationModule @P -Name "AzureDSC_Modules"