<#
.SYNOPSIS
DSC-Konfigurasjon for SessionHosts.


.DESCRIPTION
Dette er DSC-konfigurasjonen for SessionHosts. Utviklet av Øyvind Lotten Westrum i forbindelse med Bachelorprosjekt våren 2019. Oppgaven gikk ut på å konfigurere en Session Host uten manuelle steg ved bruk av Azure Automation Desired State Configuration.
Konfigurasjonen tar for seg de forskjellige stegene som er definert på Fuglane artikkel "Programfarm-Produksjon-SessionHost-Manuelletilpasninger,installasjonogoppsett" https://fuglane.it.ntnu.no/pages/viewpage.action?pageId=12386753#Programfarm-Produksjon-SessionHost-Manuelletilpasninger,installasjonogoppsett

Konfigurasjonen benytter Composite Resource med navn "SessionHostBaseline" der all konfigurasjon som er felles for alle Session Hoster er definert.

Konfigurasjonen benytter følgende egenkomposerte/videreutviklede DSC-ressurser som må importeres i Azure Automation:
- CopyAcl
- IPv6Address
- Printer
- PrinterDriver
- SessionHost (NB. Ikke testet i testmiljø)


.PARAMETER OS

Parameter "OS" spesifiserer hvilket operativsystem konfigurasjonen skal gjelde for. Det er for eksempel en konfigurasjon som kun gjelder for Windows Server 2016.

.PARAMETER Collection

Parameter "Collection" spesifiserer hvilket Session Collection konfigurasjonen skal gjelde for.


.EXAMPLE

$config = Import-AzAutomationDscConfiguration @P -SourcePath "SessionHost.ps1" -Published -Force -Verbose

$CompilateConfig = Start-AzAutomationDscCompilationJob @P -ConfigurationName $config.Name -IncrementNodeConfigurationBuild -Verbose


#>

Configuration SessionHost
{
    param(
        [Parameter(Mandatory=$true)]
        [ValidateSet("srv2019", "srv2016", "srv2012r2")]
        [string] $OS,

        [Parameter(Mandatory=$true)]
        [ValidateSet("adminfarm", "officefarm", "calcfarm", "devfarm", "legacyfarm", "kavlifarm", "edgefarm", "idifarm", "ielfarm", "telmefarm", "azdscfarm")]
        [string] $Collection
    )

    Import-DscResource -ModuleName AzureDSC_Modules -name SessionHostBaseline
    Import-DscResource -ModuleName PSDesiredStateConfiguration -name WindowsFeatureSet
    Import-DscResource -ModuleName PSDesiredStateConfiguration -name WindowsFeature
    Import-DscResource -ModuleName PSDesiredStateConfiguration -name Service
    Import-DscResource -ModuleName AzureDSC_Modules -name CopyAcl

    #$cred = Get-AutomationPSCredential "user"

    Node "$Collection.$OS"
    {
        SessionHostBaseline Baseline
        {
            # Baseline configuration from Module SessionHostComposite
        }
        # OfficeFarm og Adminfarm
        if ($Collection -eq "officefarm" -or "adminfarm") 
        {
            WindowsFeatureSet InstallWindowsFeaturesOfficeAdmin
            {
                Name                    = @("Windows-Identity-Foundation", "RSAT-AD-Powershell")
                Ensure                  = "Present"
            }
        }
        # Calcfarm
        if ($Collection -eq "calcfarm") 
        { 
            File CopyScripts 
            {
                Ensure                  = "Present"
                Type                    = "Directory"
                DestinationPath         = "$env:HOMEDRIVE\scripts" #envvariabler
                SourcePath              = "\\win.ntnu.no\shares\installshare\Dsc\Sessionhost\Scripts"
            }
        }
        #Adminfarm, Officefarm, Kavlifarm, Edgefarm, Ielfarm
        if ($Collection -eq "officefarm" -or "adminfarm" -or "kavlifarm" -or "edgefarm" -or "ielfarm") 
        {
            WindowsFeature InstallWindowsSearch
            {
                Name                    = "Search-Service"
                Ensure                  = "Present"
            }
            Service DisableWindowsSearch 
            {
                Name                    = "wsearch"
                StartupType             = "Disabled"
                State                   = "Stopped"
                DependsOn               = "[WindowsFeature]InstallWindowsSearch"
            }
        }
        # OS 2016
        if ($OS -eq "srv2016") 
        {
            WindowsFeature RemoveWindowsFeatures
            {
                Name                    = "Windows-Defender"
                Ensure                  = "Absent"
            }
            CopyAcl CopyAclUsersDefault
            {
                SourcePath              = "$env:HOMEDRIVE\users"
                DestinationPath         = "$env:HOMEDRIVE\users\default\"
                Recurse                 = $false
            }
            CopyAcl CopyAclUsersStartMenu
            {
                SourcePath              = "$env:HOMEDRIVE\users"
                DestinationPath         = "$env:HOMEDRIVE\users\Default\Appdata\Roaming\Microsoft\Windows\Start Menu\"
                Recurse                 = $true
                #PsDscRunAsCredential    = $cred
            }
        }
    } # Node
} # Configuration